@@ -8,7 +8,7 @@ require Exporter;
 our @ISA = qw( Exporter );
 our @EXPORT_OK = qw(set_page_size get_page_size);
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 0.002 $ =~ /: (\d+)\.(\d+)/;
+our $VERSION = sprintf "%d.%03d", q$Revision: 0.003 $ =~ /: (\d+)\.(\d+)/;
 
 our @COLLECTED_TEXT = ();
 our $DEFAULT_PAGE_SIZE = 25;
@@ -16,7 +16,7 @@ our $PAGE_SIZE = $DEFAULT_PAGE_SIZE;
 our $PAGE_NUM = 1;
 our ($OLD_WARN, $OLD_DIE);
 our ($WinMode, $CMDExists);
-init();
+# init();
 
 END {
     pause();
@@ -89,17 +89,17 @@ use constant VB_CANCEL => 2;
 sub new {
 	my $self = bless {}, shift;
 	# Using a "__WARN__" handler provides the way to re-direct warn statements to a MsgBox
-    $OLD_WARN = $SIG{__WARN__};
- 	$SIG{__WARN__} = sub { WarnBox(@_) };
-    return $self;
+	$OLD_WARN = $SIG{__WARN__};
+	$SIG{__WARN__} = sub { WarnBox(@_) };
+	return $self;
 }
 
 ##################################
 sub WarnBox {											# Send Warnings immediately
 	my $msg = join("\n", @_);
-	return unless $msg ne '';
+	return if $msg eq '';
 	my $answer = Win32::MsgBox($msg, VB_OK_CANCEL, 'Warning!');
-    $OLD_WARN->(@_) if $OLD_WARN;  # invoke the old handler
+	$OLD_WARN->(@_) if $OLD_WARN;  # invoke the old handler
 	die if $answer == VB_CANCEL;
 }
 
@@ -132,6 +132,7 @@ Win32::PrintBox - Redirects print STDOUT and warn statements to a message box un
 =head1 SYNOPSIS
 
     use Win32::PrintBox;
+    Win32::PrintBox::init();
     
     print "Program output\n";
     warn "Error reported: $!\n";
@@ -171,7 +172,8 @@ Sets up a handler to catch __WARN__ signals, and process them with sub C<WarnBox
 =head2 init
 
 Initialization logic.  Encapsulated in a subroutine so it can be called during 
-testing.
+testing.  This used to be called when the module was loaded, but is now left
+for the user to invoke, since it interfered with test suites.
 
 =head2 pause
 
